@@ -4,7 +4,7 @@ from unittest import TestCase
 import tree_sitter_python
 import tree_sitter_javascript
 
-from tree_sitter import Language, Parser, Query, QueryError
+from tree_sitter import Language, Parser, Query, QueryCursor, QueryError
 
 
 def collect_matches(matches):
@@ -28,7 +28,8 @@ class TestQuery(TestCase):
     def assert_query_matches(self, language, query, source, expected):
         parser = Parser(language)
         tree = parser.parse(source)
-        matches = language.query(query).matches(tree.root_node)
+        cursor = QueryCursor(Query(language, query))
+        matches = cursor.matches(tree.root_node)
         self.assertListEqual(collect_matches(matches), expected)
 
     def test_errors(self):
@@ -146,14 +147,16 @@ class TestQuery(TestCase):
         parser = Parser(self.python)
         source = b"def foo():\n  bar()\ndef baz():\n  quux()\n"
         tree = parser.parse(source)
-        query = self.python.query(
+        query = Query(
+            self.python,
             """
             (function_definition name: (identifier) @func-def)
             (call function: (identifier) @func-call)
-            """
+            """,
         )
 
-        captures = list(query.captures(tree.root_node).items())
+        cursor = QueryCursor(query)
+        captures = list(cursor.captures(tree.root_node).items())
 
         self.assertEqual(captures[0][0], "func-def")
         self.assertEqual(captures[0][1][0].start_point, (0, 4))
@@ -187,34 +190,126 @@ class TestQuery(TestCase):
         root_node = tree.root_node
 
         # function with name equal to 'fun1' -> test for #eq? @capture string
-        query1 = self.javascript.query(
+        query1 = Query(
+            self.javascript,
             """
             ((function_declaration
                 name: (identifier) @function-name)
                 (#eq? @function-name fun1))
             """
         )
-        captures1 = list(query1.captures(root_node).items())
+        cursor = QueryCursor(query1)
+        captures1 = list(cursor.captures(root_node).items())
         self.assertEqual(1, len(captures1))
         self.assertEqual(captures1[0][0], "function-name")
         self.assertEqual(captures1[0][1][0].text, b"fun1")
 
         # functions with name not equal to 'fun1' -> test for #not-eq? @capture string
-        query2 = self.javascript.query(
+        query2 = Query(
+            self.javascript,
             """
             ((function_declaration
                 name: (identifier) @function-name)
                 (#not-eq? @function-name fun1))
-        """
+            """
         )
-        captures2 = list(query2.captures(root_node).items())
+        cursor = QueryCursor(query2)
+        captures2 = list(cursor.captures(root_node).items())
         self.assertEqual(1, len(captures2))
         self.assertEqual(captures2[0][0], "function-name")
         self.assertEqual(captures2[0][1][0].text, b"fun2")
 
+    def test_text_predicates_with_callback(self):
+        parser = Parser(self.javascript)
+        source = b"""
+            keypair_object = {
+                key1: value1,
+                equal: equal
+            }
+
+            function fun1(arg) {
+                return 1;
+            }
+
+            function fun2(arg) {
+                return 2;
+            }
+
+            function fun3(arg) {
+                return 3;
+            }
+        """
+
+        def read_callable_byte_offset(byte_offset, point):
+            return source[byte_offset: byte_offset + 1]
+
+        def read_callable_point(byte_offset, point):
+            row, col = point
+            lines = source.split(b"\n")
+            if row >= len(lines):
+                return b""
+            line = lines[row]
+            if col >= len(line):
+                return b"\n"
+            return line[col:col + 1]
+
+        tree1 = parser.parse(read_callable_byte_offset)
+        root_node1 = tree1.root_node
+        tree2 = parser.parse(read_callable_point)
+        root_node2 = tree2.root_node
+
+        # function with name equal to 'fun1' -> test for #eq? @capture string
+        query1 = Query(
+            self.javascript,
+            """
+            ((function_declaration
+                name: (identifier) @function-name)
+                (#match? @function-name "fun[12]"))
+            """
+        )
+        cursor1 = QueryCursor(query1)
+        captures1 = cursor1.captures(root_node1)
+        self.assertEqual(1, len(captures1))
+        self.assertIn("function-name", captures1)
+        self.assertEqual(2, len(captures1["function-name"]))
+        self.assertEqual(captures1["function-name"][0].text, b"fun1")
+        self.assertEqual(captures1["function-name"][1].text, b"fun2")
+
+        captures2 = cursor1.captures(root_node2)
+        self.assertEqual(1, len(captures2))
+        self.assertIn("function-name", captures2)
+        self.assertEqual(2, len(captures2["function-name"]))
+        self.assertEqual(captures2["function-name"][0].text, b"fun1")
+        self.assertEqual(captures2["function-name"][1].text, b"fun2")
+
+        # functions with name not equal to 'fun1' -> test for #not-eq? @capture string
+        query2 = Query(
+            self.javascript,
+            """
+            ((function_declaration
+                name: (identifier) @function-name)
+                (#not-eq? @function-name fun1))
+            """
+        )
+        cursor2 = QueryCursor(query2)
+        captures3 = cursor2.captures(root_node1)
+        self.assertEqual(1, len(captures3))
+        self.assertIn("function-name", captures3)
+        self.assertEqual(2, len(captures3["function-name"]))
+        self.assertEqual(captures3["function-name"][0].text, b"fun2")
+        self.assertEqual(captures3["function-name"][1].text, b"fun3")
+
+        captures4 = cursor2.captures(root_node2)
+        self.assertEqual(1, len(captures4))
+        self.assertIn("function-name", captures4)
+        self.assertEqual(2, len(captures4["function-name"]))
+        self.assertEqual(captures4["function-name"][0].text, b"fun2")
+        self.assertEqual(captures4["function-name"][1].text, b"fun3")
+
     def test_text_predicates_errors(self):
         with self.assertRaises(QueryError):
-            self.javascript.query(
+            Query(
+                self.javascript,
                 """
                 ((function_declaration
                     name: (identifier) @function-name)
@@ -223,7 +318,8 @@ class TestQuery(TestCase):
             )
 
         with self.assertRaises(QueryError):
-            self.javascript.query(
+            Query(
+                self.javascript,
                 """
                 ((function_declaration
                     name: (identifier) @function-name)
@@ -232,7 +328,8 @@ class TestQuery(TestCase):
             )
 
         with self.assertRaises(QueryError):
-            self.javascript.query(
+            Query(
+                self.javascript,
                 """
                 ((function_declaration
                     name: (identifier) @function-name)
@@ -241,7 +338,8 @@ class TestQuery(TestCase):
             )
 
         with self.assertRaises(QueryError):
-            self.javascript.query(
+            Query(
+                self.javascript,
                 """
                 ((function_declaration
                     name: (identifier) @function-name)
@@ -250,7 +348,8 @@ class TestQuery(TestCase):
             )
 
         with self.assertRaises(QueryError):
-            self.javascript.query(
+            Query(
+                self.javascript,
                 """
                 ((function_declaration
                     name: (identifier) @function-name)
@@ -259,7 +358,8 @@ class TestQuery(TestCase):
             )
 
         with self.assertRaises(QueryError) as ctx:
-            self.javascript.query(
+            Query(
+                self.javascript,
                 """
                 ((function_declaration
                     name: (identifier) @function-name)
@@ -275,14 +375,17 @@ class TestQuery(TestCase):
         parser = Parser(self.python)
         source = b"def foo():\n  bar()\ndef baz():\n  quux()\n"
         tree = parser.parse(source)
-        query = self.python.query(
+        query = Query(
+            self.python,
             """
             (function_definition name: (identifier) @func-def)
             (call function: (identifier) @func-call)
             """
-        ).set_point_range(((1, 0), (2, 0)))
+        )
+        cursor = QueryCursor(query)
+        cursor.set_point_range((1, 0), (2, 0))
 
-        captures = list(query.captures(tree.root_node).items())
+        captures = list(cursor.captures(tree.root_node).items())
 
         self.assertEqual(captures[0][0], "func-call")
         self.assertEqual(captures[0][1][0].start_point, (1, 2))
@@ -292,14 +395,17 @@ class TestQuery(TestCase):
         parser = Parser(self.python)
         source = b"def foo():\n  bar()\ndef baz():\n  quux()\n"
         tree = parser.parse(source)
-        query = self.python.query(
+        query = Query(
+            self.python,
             """
             (function_definition name: (identifier) @func-def)
             (call function: (identifier) @func-call)
             """
-        ).set_byte_range((10, 20))
+        )
+        cursor = QueryCursor(query)
+        cursor.set_byte_range(10, 20)
 
-        captures = list(query.captures(tree.root_node).items())
+        captures = list(cursor.captures(tree.root_node).items())
         self.assertEqual(captures[0][0], "func-call")
         self.assertEqual(captures[0][1][0].start_point, (1, 2))
         self.assertEqual(captures[0][1][0].end_point, (1, 5))
